@@ -1,6 +1,7 @@
 from ._error import NotInstalled
 from ._grid import grid, random_grid
 from ._base import memlist, memfile, memfunc
+from ._runner import Runner
 from ._util import time_taken
 
 try:
@@ -8,13 +9,7 @@ try:
 except ModuleNotFoundError:
     memweb = NotInstalled("memweb", "web")
 
-try:
-    from memo._wandb import memwandb
-except ModuleNotFoundError:
-    memwandb = NotInstalled("memwandb", "wandb")
 
-
-__version__ = "0.1.1"
 __all__ = [
     "grid",
     "random_grid",
@@ -22,6 +17,6 @@ __all__ = [
     "memfile",
     "memfunc",
     "memweb",
-    "memwandb",
     "time_taken",
+    "Runner",
 ]
