@@ -1,5 +1,6 @@
 import json
 import pytest
+import numpy as np
 
 from memo import memfile
 
@@ -7,7 +8,6 @@ from memo import memfile
 def confirm_file_contents(fpath, data):
     with open(fpath, "r") as f:
         data_read = [json.loads(j) for j in f.read().split("\n") if j != ""]
-    print(data_read)
     for i, d in enumerate(data_read):
         assert data[i] == d
 
@@ -35,3 +35,26 @@ def test_base_multiple_calls(tmp_path):
     for i in range(1, 5):
         count_values(a=1)
         confirm_file_contents(filepath, [{"a": 1, "sum": 1}] * i)
+
+
+def test_also_works_with_numpy1(tmp_path):
+    filepath = f"{tmp_path}/file.jsonl"
+
+    @memfile(filepath=filepath)
+    def count_values(**kwargs):
+        return {"sum": sum(kwargs.values())}
+
+    for i in range(1, 5):
+        count_values(a=np.array([1]))
+        confirm_file_contents(filepath, [{"a": [1], "sum": [1]}] * i)
+
+
+def test_also_works_with_numpy2(tmp_path):
+    filepath = f"{tmp_path}/file.jsonl"
+
+    @memfile(filepath=filepath)
+    def count_values(**kwargs):
+        return {"sum": sum(kwargs.values())}
+
+    count_values(a=np.array([1])[0])
+    confirm_file_contents(filepath, [{"a": 1, "sum": 1}])
